@@ -8,9 +8,9 @@ def create_celery_app(project_folder):
     from celery import Celery
     celery_settings = get_settings(settings_type='celery')
     celery_app = Celery(__name__)
+    celery_settings['imports'] = collect_app_tasks(project_folder=project_folder) + ['handlers', 'routes']
     celery_app.config_from_object(celery_settings, force=True)
-    import_tasks = collect_framework_tasks() + collect_app_tasks(project_folder=project_folder)
-    print(import_tasks)
+    import_tasks = collect_framework_tasks()
     for pkg, file in import_tasks:
         celery_app.autodiscover_tasks(packages=[pkg], related_name=file, force=True)
     return celery_app
@@ -18,13 +18,14 @@ def create_celery_app(project_folder):
 
 def collect_app_tasks(project_folder):
     import os
-    tasks = list()
-    for root, folders, files in os.walk(os.path.join(project_folder, 'tasks')):
-        base = root.replace(project_folder, '').replace('/', '.').strip('.')
-        for f in [f.replace('.py', '') for f in files if
+    tasks = set()
+    for i in os.walk(os.path.join(project_folder, 'tasks')):
+        base = i[0].replace(project_folder, '').replace('/', '.').strip('.')
+        tasks.add(base)
+        for f in [f.replace('.py', '') for f in i[-1] if
                   f.endswith('.py') and f not in {'__init__.py'} and "pycache" not in f]:
-            tasks.append((base, f))
-    return tasks
+            tasks.add(base + '.' + f)
+    return list(tasks)
 
 
 def collect_framework_tasks():
